@@ -30,7 +30,7 @@ import click
 from click import echo, style
 from click.termui import get_terminal_size
 
-__version__ = "0.3.0"
+__version__ = "0.3.1"
 __author__ = "Steven Loria"
 __license__ = "MIT"
 
@@ -203,7 +203,7 @@ def search(query, n_results, web):
         searcher = Searcher()
         results = searcher.search(query, n=n_results)
         first_line = style('Search results for "{0}"\n'.format(query), bold=True)
-        click.echo_via_pager(
+        echo(
             first_line +
             '\n'.join([format_result(result) for result in results])
         )
